==> aws-cdk.aws-cloud9-1.154.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_cloud9_CfnEnvironmentEC2Props(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    try {
        if (!visitedObjects.has(p.tags))
            require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    }
    finally {
        visitedObjects.delete(p);
    }
}
function _aws_cdk_aws_cloud9_CfnEnvironmentEC2(p) {
}
function _aws_cdk_aws_cloud9_CfnEnvironmentEC2_RepositoryProperty(p) {
}
function _aws_cdk_aws_cloud9_IEc2Environment(p) {
}
function _aws_cdk_aws_cloud9_Ec2EnvironmentProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    try {
        if (!visitedObjects.has(p.clonedRepositories))
            _aws_cdk_aws_cloud9_CloneRepository(p.clonedRepositories);
    }
    finally {
        visitedObjects.delete(p);
    }
}
function _aws_cdk_aws_cloud9_Ec2Environment(p) {
}
function _aws_cdk_aws_cloud9_CloneRepository(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage.trim()}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
function getPropertyDescriptor(obj, prop) {
    const descriptor = Object.getOwnPropertyDescriptor(obj, prop);
    if (descriptor) {
        return descriptor;
    }
    const proto = Object.getPrototypeOf(obj);
    const prototypeDescriptor = proto && getPropertyDescriptor(proto, prop);
    if (prototypeDescriptor) {
        return prototypeDescriptor;
    }
    return {};
}
const visitedObjects = new Set();
class DeprecationError extends Error {
    constructor(...args) {
        super(...args);
        Object.defineProperty(this, "name", {
            configurable: false,
            enumerable: true,
            value: "DeprecationError",
            writable: false,
        });
    }
}
module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_cloud9_CfnEnvironmentEC2Props, _aws_cdk_aws_cloud9_CfnEnvironmentEC2, _aws_cdk_aws_cloud9_CfnEnvironmentEC2_RepositoryProperty, _aws_cdk_aws_cloud9_IEc2Environment, _aws_cdk_aws_cloud9_Ec2EnvironmentProps, _aws_cdk_aws_cloud9_Ec2Environment, _aws_cdk_aws_cloud9_CloneRepository };

==> aws-cdk.aws-cloud9-1.172.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_cloud9_CfnEnvironmentEC2Props(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    try {
        if (!visitedObjects.has(p.tags))
            require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    }
    finally {
        visitedObjects.delete(p);
    }
}
function _aws_cdk_aws_cloud9_CfnEnvironmentEC2(p) {
}
function _aws_cdk_aws_cloud9_CfnEnvironmentEC2_RepositoryProperty(p) {
}
function _aws_cdk_aws_cloud9_IEc2Environment(p) {
}
function _aws_cdk_aws_cloud9_ConnectionType(p) {
}
function _aws_cdk_aws_cloud9_Ec2EnvironmentProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    try {
        if (!visitedObjects.has(p.clonedRepositories))
            _aws_cdk_aws_cloud9_CloneRepository(p.clonedRepositories);
        if (!visitedObjects.has(p.connectionType))
            _aws_cdk_aws_cloud9_ConnectionType(p.connectionType);
    }
    finally {
        visitedObjects.delete(p);
    }
}
function _aws_cdk_aws_cloud9_Ec2Environment(p) {
}
function _aws_cdk_aws_cloud9_CloneRepository(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage.trim()}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
function getPropertyDescriptor(obj, prop) {
    const descriptor = Object.getOwnPropertyDescriptor(obj, prop);
    if (descriptor) {
        return descriptor;
    }
    const proto = Object.getPrototypeOf(obj);
    const prototypeDescriptor = proto && getPropertyDescriptor(proto, prop);
    if (prototypeDescriptor) {
        return prototypeDescriptor;
    }
    return {};
}
const visitedObjects = new Set();
class DeprecationError extends Error {
    constructor(...args) {
        super(...args);
        Object.defineProperty(this, "name", {
            configurable: false,
            enumerable: true,
            value: "DeprecationError",
            writable: false,
        });
    }
}
module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_cloud9_CfnEnvironmentEC2Props, _aws_cdk_aws_cloud9_CfnEnvironmentEC2, _aws_cdk_aws_cloud9_CfnEnvironmentEC2_RepositoryProperty, _aws_cdk_aws_cloud9_IEc2Environment, _aws_cdk_aws_cloud9_ConnectionType, _aws_cdk_aws_cloud9_Ec2EnvironmentProps, _aws_cdk_aws_cloud9_Ec2Environment, _aws_cdk_aws_cloud9_CloneRepository };
